==> haskell-aeson-better-errors-0.9.1.3-65.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-better-errors
version:              0.9.1.3
visibility:           public
id:                   aeson-better-errors-0.9.1.3-I6N4BBe6LfBEk5gaGiecpe
key:                  aeson-better-errors-0.9.1.3-I6N4BBe6LfBEk5gaGiecpe
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  394474a4dfe4f9ecae7ce3a4186c540e
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.3-I6N4BBe6LfBEk5gaGiecpe
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO mtl-2.3.1
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.3-66-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-better-errors
version:              0.9.1.3
visibility:           public
id:                   aeson-better-errors-0.9.1.3-2uIVkuSZqUl7J3Bw2ULJag
key:                  aeson-better-errors-0.9.1.3-2uIVkuSZqUl7J3Bw2ULJag
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  dddda5d76f31fb72b7d2413b7262b12e
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.3-2uIVkuSZqUl7J3Bw2ULJag
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO mtl-2.3.1
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
